from flask import Flask, render_template, request, send_file
import yt_dlp
import os

app = Flask(__name__)

# Define the download folder path
DOWNLOAD_FOLDER = 'downloads'
os.makedirs(DOWNLOAD_FOLDER, exist_ok=True)

@app.route('/')
def index():
    return render_template('index.html')

@app.route('/download', methods=['POST'])
def download_video():
    url = request.form.get('url')
    if not url:
        return "Please provide a URL", 400

    try:
        # Download YouTube video with YT-DLP
        ydl_opts = {
            'format': 'best',  # 'best' downloads the best quality available
            'outtmpl': os.path.join(DOWNLOAD_FOLDER, '%(title)s.%(ext)s')
        }

        with yt_dlp.YoutubeDL(ydl_opts) as ydl:
            info = ydl.extract_info(url, download=True)
            file_path = ydl.prepare_filename(info)

        # Serve the downloaded file
        return send_file(file_path, as_attachment=True)
    
    except Exception as e:
        error_message = f"An error occurred: {str(e)}"
        return render_template('index.html', error=error_message)

if __name__ == "__main__":
    app.run(debug=True)
